Struct ReflectMapEntitiesResource
pub struct ReflectMapEntitiesResource { /* private fields */ }Expand description
For a specific type of resource, this maps any fields with values of type Entity to a new world.
Since a given Entity ID is only valid for the world it came from, when performing deserialization
any stored IDs need to be re-allocated in the destination world.
See SceneEntityMapper and MapEntities for more information.
Implementations
impl ReflectMapEntitiesResource
impl ReflectMapEntitiesResource
pub fn map_entities(
&self,
world: &mut World,
entity_map: &mut HashMap<Entity, Entity, EntityHash>,
)
pub fn map_entities( &self, world: &mut World, entity_map: &mut HashMap<Entity, Entity, EntityHash>, )
A method for applying MapEntities behavior to elements in an EntityHashMap<Entity>.