Struct ReflectMessageFns
pub struct ReflectMessageFns {
pub write_message: fn(&mut World, &(dyn PartialReflect + 'static), &TypeRegistry),
}Expand description
The raw function pointers needed to make up a ReflectMessage.
This is used when creating custom implementations of ReflectMessage with
ReflectMessage::new().
Note: Creating custom implementations of
ReflectMessageis an advanced feature that most users will not need. Usually aReflectMessageis created for a type by deriving [Reflect] and adding the#[reflect(Message)]attribute. After adding the event to the [TypeRegistry], itsReflectMessagecan then be retrieved when needed.
Creating a custom ReflectMessage may be useful if you need to create new
message types at runtime, for example, for scripting implementations.
By creating a custom ReflectMessage and inserting it into a type’s
[TypeRegistration][bevy_reflect::TypeRegistration], you can modify the way
that reflected messages of that type will be written to the Bevy world.
Fields
write_message: fn(&mut World, &(dyn PartialReflect + 'static), &TypeRegistry)Function pointer implementing ReflectMessage::write_message.
Implementations
impl ReflectMessageFns
impl ReflectMessageFns
pub fn new<M>() -> ReflectMessageFnswhere
M: Message + FromReflect + TypePath,
pub fn new<M>() -> ReflectMessageFnswhere
M: Message + FromReflect + TypePath,
Get the default set of ReflectMessageFns for a specific event type
using its [FromType] implementation.
This is useful if you want to start with the default implementation before overriding some of the functions to create a custom implementation.