Struct ReflectBundle
pub struct ReflectBundle(/* private fields */);Expand description
A struct used to operate on reflected Bundle trait of a type.
A ReflectBundle for type T can be obtained via
[bevy_reflect::TypeRegistration::data].
Implementations
impl ReflectBundle
impl ReflectBundle
pub fn insert(
&self,
entity: &mut EntityWorldMut<'_>,
bundle: &(dyn Reflect + 'static),
registry: &TypeRegistry,
)
pub fn insert( &self, entity: &mut EntityWorldMut<'_>, bundle: &(dyn Reflect + 'static), registry: &TypeRegistry, )
pub fn apply<'a>(
&self,
entity: impl Into<EntityMut<'a>>,
bundle: &(dyn Reflect + 'static),
registry: &TypeRegistry,
)
pub fn apply<'a>( &self, entity: impl Into<EntityMut<'a>>, bundle: &(dyn Reflect + 'static), registry: &TypeRegistry, )
pub fn apply_or_insert(
&self,
entity: &mut EntityWorldMut<'_>,
bundle: &(dyn Reflect + 'static),
registry: &TypeRegistry,
)
pub fn apply_or_insert( &self, entity: &mut EntityWorldMut<'_>, bundle: &(dyn Reflect + 'static), registry: &TypeRegistry, )
Uses reflection to set the value of this Bundle type in the entity to the given value or insert a new one if it does not exist.
pub fn remove(&self, entity: &mut EntityWorldMut<'_>)
pub fn remove(&self, entity: &mut EntityWorldMut<'_>)
Removes this Bundle type from the entity. Does nothing if it doesn’t exist.
pub fn new(fns: ReflectBundleFns) -> ReflectBundle
pub fn new(fns: ReflectBundleFns) -> ReflectBundle
Create a custom implementation of ReflectBundle.
This is an advanced feature, useful for scripting implementations, that should not be used by most users unless you know what you are doing.
Usually you should derive [Reflect] and add the #[reflect(Bundle)] bundle
to generate a ReflectBundle implementation automatically.
See ReflectBundleFns for more information.
pub fn fn_pointers(&self) -> &ReflectBundleFns
pub fn fn_pointers(&self) -> &ReflectBundleFns
The underlying function pointers implementing methods on ReflectBundle.
This is useful when you want to keep track locally of an individual function pointer.
Calling [TypeRegistry::get] followed by
TypeRegistration::data::<ReflectBundle> can be costly if done several
times per frame. Consider cloning ReflectBundle and keeping it
between frames, cloning a ReflectBundle is very cheap.
If you only need a subset of the methods on ReflectBundle,
use fn_pointers to get the underlying ReflectBundleFns
and copy the subset of function pointers you care about.